@@ -76,9 +76,9 @@
  * any ordering constraints the engine might impose.  Groups larger than 16
  * outf()'s should be split up into two or more groups as needed (but not
  * necessarily wanted).  The outf() groups that result should be immediately
- * preceeded by an ATIMach64WaitForFIFO(n) call, where "n" is the number of
+ * preceded by an ATIMach64WaitForFIFO(n) call, where "n" is the number of
  * outf()'s in the group with the exception that groups containing a single
- * outf() should not be thus preceeded.  This means "n" should not be less than
+ * outf() should not be thus preceded.  This means "n" should not be less than
  * 2, nor larger than 16.
  */
 
@@ -236,7 +236,7 @@ do {                                                            \
  * Set upon DRISwapContext and when DRI accesses the GPU engine
  * from within the server, see DRIInitBuffers/DRIMoveBuffers.
  *
- * Forces the EXA/XAA software paths to sync before accessing the FB memory.
+ * Forces the EXA software paths to sync before accessing the FB memory.
  */
 static __inline__ void ATIDRIMarkSyncInt(ScrnInfoPtr _pScrInfo)
 {
@@ -245,16 +245,12 @@ static __inline__ void ATIDRIMarkSyncInt(ScrnInfoPtr _pScrInfo)
     if (_pATI->useEXA)
         exaMarkSync(_pScrInfo->pScreen);
 #endif
-#ifdef USE_XAA
-    if (!_pATI->useEXA)
-        SET_SYNC_FLAG(_pATI->pXAAInfo); /* NeedToSync = TRUE */
-#endif
 }
 
 /*
  * Set upon DRISwapContext and when the server acquires the DRI lock.
  *
- * Forces the EXA/XAA accelerated paths to sync before accessing the GPU engine.
+ * Forces the EXA accelerated paths to sync before accessing the GPU engine.
  */
 static __inline__ void ATIDRIMarkSyncExt(ScrnInfoPtr _pScrInfo)
 {
@@ -271,12 +267,6 @@ static __inline__ void ATIDRISync(ScrnInfoPtr _pScrInfo)
         if (_pATI->NeedDRISync) exaWaitSync(_pScrInfo->pScreen);
     }
 #endif
-#ifdef USE_XAA
-    if (_pATI->directRenderingEnabled && _pATI->pXAAInfo)
-    {
-        if (_pATI->NeedDRISync) (*_pATI->pXAAInfo->Sync)(_pScrInfo);
-    }
-#endif
 }
 
 #define ATIDRILock(_pScrInfo)                   \
